' USFS_FDR Test Program
' Date: 082309
' Author: Richard McCue

con
  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000


' Create a directory matrix for storing data on thumb drive.
' Assign a block of memory to record the number of downloads.
' Assign a block of memory to record the last memory location recorded to before shutdown.
' Clear the remaining memory contents every time the device is manually shutdown after a jump.
   SERNUM        = %0000_0001

   LF            = 10
   FF            = 12
   CR            = 13
   Space         = " "
   Tab           = 9
   
'pins-----------------------------------------------
' ** BANK 4
'MEMSDA2         = 31   
'MEMSCL2         = 30 'SHT_CLOCK       = 16  
' = 29
' = 28
RLED            = 27
GLED            = 26
MEMSDA1         = 25                   ' Memory I2C bus
MEMSCL1         = 24


'** BANK 3
DLPWR           = 23                   ' turns on datalogger power
Power           = 22                   ' hold power on through optical coupler
ENTER           = 21                   ' Enter button input
ADCPWR          = 20                   ' Turns on analog power
ADCDRDY         = 19                   ' Data ready pin
ADCSDO          = 18                   ' Set MAX1416 Data out Pin                    
ADCSDI          = 17                   ' Set MAX1416 Data in Pin  
ADCCLK          = 16                   ' Set MAX1416 Clock Pin

'** BANK 2
DLRTS           = 15                   ' Datalogger cts pin 6
DLRXD           = 14                   ' Datalogger txd pin 5
DLTXD           = 13                   ' Datalogger rxd pin 4
DLCTS           = 12                   ' Datalogger rts pin 2

A_FFI           = 11                   ' Acc Free fall Interrupt
A_SDA           = 10                   ' Acc I2C Bus
A_SCL           = 9
'               = 8
                 
'** BANK 1
'SHT_DATA        = 7 
'SHT_CLOCK       = 6  
C_SDA           = 5                   '' HMC I2C Bus                            
C_SCL           = 4
'Compass--------------------------------------------
C_ADDR = %00110010     
'Accelerometer--------------------------------------              
A_Addr = %00111010
'Pressure Transducers-------------------------------
Comm1    = %00000100
WrClock1 = %00100000         ' write Clock Register
rdClock1 = %00101000
Clock1   = %10110100

Comm2    = %00000101
WrClock2 = %00100001         ' write Clock Register
rdClock2 = %00101001
Clock2   = %10110100
          
WrSetup1 = %00010000          'write Setup register
rdSetup1 = %00011000
Setup1   = %00000100
Stop1    = %00000101
 
WrSetup2 = %00010001          'write Setup register
rdSetup2 = %00011001
Setup2   = %00000100
Stop2    = %00000101
  
ReadCom1 = %00001000
ReadCom2 = %00001001
                     
ReadADC1 = $38 ''%00111000          read Data Register
ReadADC2 = $39 ''%00111001          read Data Register
'I2C registers for the HMC6443----------------------
  HMC6343_POST_ACCEL            = $40
  HMC6343_POST_MAG              = $45
  HMC6343_POST_HEADING          = $50
  HMC6343_POST_TILT             = $55
  HMC6343_READ_EEPROM           = $E1
  
  'EEPROM Addresses
  HMC6343_ADDR                  = %0000_0000
  HMC6343_VER                   = %0000_0010
  HMC6343_MODE1                 = %0000_0100
  HMC6343_MODE2                 = %0000_0101

var
  byte  Counter, index, sdval, {recind shutdown Value} ExitVal, ComReg    
  long  MEMADDR, memloc,  eepromLocation, EEpromAddr, EEpromData, MEMSCL, LastEEPROM, LastADDR, LastBANK 
  long  AccStack[1000]
  long  CompStack[1000]
  long  ADCStack[1000]
  'long  SHTStack[1000]
  long  MEMStack[1000]
  long  Alt, Speed, AccX, AccY, AccZ, MagX, MagY, MagZ, HeadX, HeadY, HeadZ
  long  TiltX, TiltY, Temp, Hum, difcnt, i2cSlaveCounter, i2cAddress, DropCounter, Time, TEMPVAR  
obj

  A_I2C   : "i2cObject"
  HMC     : "hmc6343Object"
  SPI     : "SPI_Spin"
  'SHT1x   : "Sensirion"
  'Ser     : "Parallax Serial Terminal"
  i2cObject     : "basic_i2c_driver"
  flash   : "USBdrive_mod"                             
  
pub powerup
  '
  dira[power]~~
  dira[Gled]~~
  dira[Rled]~~
  'dira[ADCRST]~~
  
  outa[power] := 1
  outa[rled] := 1  
  waitcnt(clkfreq*2 + cnt)
  sdval := 0
  'recind := 0
  ExitVal := 0 
  repeat 21
    !outa[Rled]
    if ina[ENTER] == 0
      outa[Rled] := 0
      coginit(7, download, @MEMstack)
      main     
    waitcnt(clkfreq/3 + cnt)
  
  startcog

pub startcog
  coginit(2, Accel_LIS, @Accstack)
  waitcnt(clkfreq/10 + cnt)
  coginit(3, compass, @Compstack)
  waitcnt(clkfreq/10 + cnt)
  coginit(4, ADC, @ADCStack)
  waitcnt(clkfreq/10 + cnt)
  'coginit(5, SHT, @SHTstack)
  'waitcnt(clkfreq/10 + cnt)
  coginit(6, WriteMemory, @MEMstack)
  waitcnt(clkfreq/10 + cnt) 
  'Ser.Start(230400)
  repeat 18
    !outa[Rled]
    waitcnt(clkfreq/3 + cnt)   
  
  main
pub main
  repeat until ina[ENTER] == 0
    outa[Gled] := 1
    if sdval == 1
      shutdown
    
  button_Check


pub button_check
  waitcnt(clkfreq * 2 + cnt)
  if ina[ENTER] == 0
    outa[Rled] := 1
    cogstop(6)
    StoreInfo
    ExitVal := 1
    if sdval := 1
      waitcnt(clkfreq*7 + cnt)
      shutdown
  main
  
pub WriteMemory    ' WRITE MEMORY ----------------------
  MEMSCL := MEMSCL1
  i2cObject.Initialize(MEMSCL)
  waitcnt((clkfreq*2)+cnt)
      
  i2cScan(MEMSCL1)
  waitcnt(clkfreq + cnt)
  'i2cScan(MEMSCL2)
  'waitcnt(clkfreq + cnt)
  'recind := 1
  index := 0
  counter := 0
  Time := cnt
  repeat 3
    if counter == 2
      sdval := 1
      cogstop(6)
    repeat while index < 8
      case index
        0: EEpromAddr := %1010_0000
           eepromLocation := $0060                      
        1: EEpromAddr := %1010_1000
           eepromLocation := $0000 
        2: EEpromAddr := %1010_0010
           eepromLocation := $0000
        3: EEpromAddr := %1010_1010
           eepromLocation := $0000
        4: EEpromAddr := %1010_0100
           eepromLocation := $0000
        5: EEpromAddr := %1010_1100
           eepromLocation := $0000
        6: EEpromAddr := %1010_0110
           eepromLocation := $0000
        7: EEpromAddr := %1010_1110
           eepromLocation := $0000
      index ++
      if i2cObject.devicePresent(MEMSCL,eepromAddr) == true
        repeat while eepromLocation < 64000   ' <-- Temporary Restriction
          Waitcnt(time += 8_000_000)
          EEPROM_Write'(MEMSCL)
      else
        ''Ser.str(string("EEPROM Missing"))
        
    'MEMSCL := MEMSCL2
    index := 0    
    Counter ++    
     
PRI EEPROM_Write'(MEMSCL) '|   ackbit
        'Ser.position(0,11) 
        'difcnt := cnt' write long
        eepromData := ||Alt
        write
        eepromData := ||Speed 
        write
        eepromData := ||AccX
        write
        eepromData := ||AccY 
        write
        eepromData := ||AccZ
        write
        {eepromData := ||MagX
        write
        eepromData := ||MagY
        write
        eepromData := ||MagZ 
        write }
        eepromData := ||HeadX
        write
        'eepromData := ||HeadY 
        'write
        'eepromData := ||HeadZ
        'write
        'eepromData := ||TiltX
        'write
        'eepromData := ||TiltY
        'write
        eepromData := Temp
        write
        eepromData := Hum
        write
        'difcnt := cnt - difcnt
        
        'Ser.dec(Difcnt)
        'Ser.str(string("    "))
             
Pri Write'(MEMSCL)
  i2cObject.WriteLong(MEMSCL, EEPROMAddr, eepromLocation, eepromData)
  'Ser.str(String("Pin="))
  'Ser.dec(MEMSCL)
  'Ser.str(string(" Write Location="))
  'Ser.dec(eepromLocation)
  'Ser.str(string(", data="))
  'Ser.dec(eepromData)
  'Ser.newline 
  eepromLocation += 4
  
   
pub download  '  DOWNLOAD  ------------------------------------
dira[dlpwr]~~
outa[dlpwr] := 1

MEMSCL := MEMSCL1
  'Ser.Start(230400)

  i2cScan(MEMSCL1)
  waitcnt(clkfreq +cnt)
  'i2cScan(MEMSCL2)
  'waitcnt(clkfreq +cnt)
     
  i2cObject.Initialize(MEMSCL)

  'QUERY MEMORY LOCATION TO GET FOLDER/FILE NAME DATA.
  EEpromAddr := %1010_0000
  eepromLocation := $0000 
  DropCounter := i2cObject.ReadLong(MEMSCL, EEPROMAddr, eepromLocation)      
  DropCounter ++
    'Ser.str(string("Drop Count = "))
    'Ser.dec(dropcounter)
    'Ser.newline
  eepromLocation += 4
  LastEEPROM := i2cObject.ReadLong(MEMSCL, EEPROMAddr, eepromLocation)
    'Ser.str(string("Last MEM Loc = "))
    'Ser.dec(LastEEPROM)
    'Ser.newline
  eepromLocation += 4 
  LastADDR := i2cObject.ReadLong(MEMSCL, EEPROMAddr, eepromLocation)
    'Ser.str(string("Last Mem Addr = "))
    'Ser.bin(LastADDR,8)
    'Ser.newline
  eepromLocation += 4
  LastBANK := i2cObject.ReadLong(MEMSCL, EEPROMAddr, eepromLocation)
    'Ser.str(string("Last Bank = "))
    'Ser.dec(LastBANK)
    'Ser.newline   
  {This is where we compare drop counter to the Data block to get the folder and file info

  Lookup data dropcounter/10 assign as @FolderName
  Lookup data dropcounter//10 assign as @FileName}
  waitcnt(clkfreq + cnt)
  'Ser.str(String("Locating Drive...."))    
   
  waitcnt(clkfreq*2 + cnt)        'Used for cold startup of MemoryStick
  flash.start(DLTXD,DLRTS,DLRXD,DLCTS, 9600)
  waitcnt(clkfreq/4 + cnt)
  flash.setBaudRate'(divisor)
  waitcnt(clkfreq + cnt)        'Used for cold startup of MemoryStick
  flash.start(DLTXD,DLRTS,DLRXD,DLCTS, 19200)
  waitcnt(clkfreq/4 + cnt)
  flash.setDiskBaudRate'(divisor)
  
 
  
  waitcnt(clkfreq + cnt)         'Wait time between operations
  flash.openForWrite(@filename)
  
  'Ser.str(String("Found"))
  'Ser.newline
  
  index := 0
  counter := 0
  'eepromLocation := $0020 'Leaves space for the Drop Sequence Number 
    
  repeat 3
    if counter == 2
      Exit_DL
    repeat while index < 8
      'if index := 8
      '  sdval := 1
      '  abort
      case index
        0: EEpromAddr := %1010_0000
           eepromLocation := $0060                      
        1: EEpromAddr := %1010_1000
           eepromLocation := $0000 
        2: EEpromAddr := %1010_0010
           eepromLocation := $0000
        3: EEpromAddr := %1010_1010
           eepromLocation := $0000
        4: EEpromAddr := %1010_0100
           eepromLocation := $0000
        5: EEpromAddr := %1010_1100
           eepromLocation := $0000
        6: EEpromAddr := %1010_0110
           eepromLocation := $0000
        7: EEpromAddr := %1010_1110
           eepromLocation := $0000
      index ++  
      if i2cObject.devicePresent(MEMSCL,eepromAddr) == true
          ''Ser.str(string("EEPROM Present="))
          ''Ser.bin(EEpromAddr, 8)
          ''Ser.newline
        repeat while eepromlocation < 64000 ' <--Temporary restriction
          if exitVal == 1
            Exit_DL
          EEPROM_read
          WriteUSB
      'else
      '      'Ser.str(string("EEPROM Missing"))    
              
    'MEMSCL := MEMSCL2
    index := 0    
    Counter ++      
    
PRI EEPROM_read '|   ackbit
        read   
        Alt := eepromData
        read
        Speed := eepromData
        read
        ACCX := eepromData 
        read
        AccY := eepromData
        read
        AccZ := eepromData
        {read
        MagX := eepromData 
        read
        MagY := eepromData 
        read
        magZ := eepromData}  
        read
        HeadX := eepromData 
        'read
        'HeadY := eepromData 
        'read
        'HeadZ := eepromData 
        'read
        'TiltX := eepromData 
        'read
        'TiltY := eepromData
        read
        Temp := eepromData 
        read
        Hum := eepromData 
       
pri read
  if eepromLocation == LastEEPROM
    if EEPROMAddr == LastADDR
      if MEMSCL == LastBank
        'Ser.str(string(" <<< Shutting Down >>>"))
        Exit_DL
  eepromData := 0
  eepromData := i2cObject.ReadLong(MEMSCL, EEPROMAddr, eepromLocation)
  'Ser.str(string("Pin="))
  'Ser.dec(MEMSCL)
  'ser.position(0,11)                
  'Ser.str(string(" Read Location="))
  'Ser.dec(eepromLocation)
  'Ser.str(string(", data="))
  'Ser.dec(eepromData)
  'Ser.newline 
  eepromLocation +=4       
  'waitcnt(clkfreq/1000+cnt)
  
pub WriteUSB
    'Ser.position(0,11)
    flash.writedec(alt)
    waitcnt(clkfreq/6000 + cnt)
    flash.writedec(Speed)
    waitcnt(clkfreq/6000 + cnt)
    flash.writedec(AccX)
    waitcnt(clkfreq/6000 + cnt)
    flash.writedec(AccY)
    waitcnt(clkfreq/6000 + cnt)
    flash.writedec(AccZ)
    waitcnt(clkfreq/6000 + cnt)
    {flash.writedec(MagX)
    waitcnt(clkfreq/6000 + cnt)
    flash.writedec(MagY)
    waitcnt(clkfreq/6000 + cnt)
    flash.writedec(MagZ)
    waitcnt(clkfreq/6000 + cnt)}
    flash.writedec(HeadX)
    waitcnt(clkfreq/6000 + cnt)
    'flash.writedec(HeadY)
    'waitcnt(clkfreq/6000 + cnt)
    'flash.writedec(HeadZ)
    'waitcnt(clkfreq/6000 + cnt)
    'flash.writedec(TiltX)
    'waitcnt(clkfreq/6000 + cnt)
    'flash.writedec(TiltX)
    'waitcnt(clkfreq/6000 + cnt)
    flash.writedec(Temp)
    waitcnt(clkfreq/6000 + cnt)
    flash.writedec(Hum)
    waitcnt(clkfreq/6000 + cnt)
    flash.write(string(13))
    waitcnt(clkfreq/6000 + cnt)
    
pub EXIT_DL
  flash.close(@filename)
  MEMSCL := MEMSCL1
  EEpromAddr := %1010_0000
  eepromLocation := $0000 
  i2cObject.WriteLong(MEMSCL, EEPROMAddr, eepromLocation, DropCounter) 
  Waitcnt(clkfreq*6 + cnt)
  SDval := 1
  cogstop(7)

pub Shutdown  'SHUTDOWN  ---------------------------------------------------
  outa[rled] := 1
  waitcnt(clkfreq + cnt)
  outa[gled] := 1
  waitcnt(clkfreq + cnt)  

  !outa[power]
  
{
PUB SHT  'TEMPERATURE AND HUMIDITY -----------------------------------------  
                                      
  sht1x.start(SHT_DATA, SHT_CLOCK)                        ' start sensirion object
  repeat  
    Temp := sht1x.readTemperature 
    Hum := sht1x.readHumidity
    waitcnt(cnt + clkfreq*2)
}
PUB Accel_LIS  'ACCELEROMETER------------------------------------------------------ 
                 
   A_I2C.Init(A_SDA,A_SCL,false)     
   
   Waitcnt(clkfreq + cnt)                      
   writeRegister($20,%01000111)   ' power up! ctr reg1      
   Waitcnt(clkfreq + cnt)
   writeRegister($21,%00000000)   'Set high G mode
   Waitcnt(clkfreq + cnt)
  
   repeat  
     AccX := printRegisterx
     AccY := printRegistery
     AccZ := printRegisterz
     waitcnt(clkfreq/20 + cnt)
    
               
pri printRegisterx | x, c, register
  register := $28 | %10000000                          
  c.byte[0]:=A_I2C.readLocation(A_ADDR,register,8,8)
  register := $29 | %10000000
  c.byte[1]:=A_I2C.readLocation(A_ADDR,register,8,8)
  c := ~~c
  x := c == NEGX                                                            'Check for max negative
  if c < 0
    c := ||(c+x)                                                        'If negative, make positive; adjust for max negative
    'Char("-")  
  return c
  
pri printRegistery | x, c, register      
  register := $2A | %10000000                          
  c.byte[0]:=A_I2C.readLocation(A_ADDR,register,8,8)
  register := $2B | %10000000
  c.byte[1]:=A_I2C.readLocation(A_ADDR,register,8,8)
  c := ~~c
  x := c == NEGX                                                            'Check for max negative
  if c < 0
    c := ||(c+x)                                                        'If negative, make positive; adjust for max negative
    'Char("-") 
  return c
  
pri printRegisterz | x, c, register  
  register := $2C | %10000000                          
  c.byte[0]:=A_I2C.readLocation(A_ADDR,register,8,8)
  register := $2D | %10000000
  c.byte[1]:=A_I2C.readLocation(A_ADDR,register,8,8)
  c := ~~c
  x := c == NEGX                                                            'Check for max negative
  if c < 0
    c := ||(c+x)                                                        'If negative, make positive; adjust for max negative
    'Char("-") 
  return c
  
    
pri writeRegister(register,value)       
  register |= %00000000                          
  A_I2C.writeLocation(A_ADDR,register,value, 8,8)

Pub Compass | X, Y, Z 'COMPASS-------------------------------------------------------------  
  waitcnt(clkfreq*3 + cnt)                              'delay for serging
  i2cObject.Initialize(C_SCL)
  repeat
    {hmc.GetMag(C_SCL, C_ADDR,@X,@Y,@Z)
    MagX := X
    MagY := Y
    MagZ := Z
    X := 0
    y := 0
    Z := 0}
    hmc.GetHeading(C_SCL, C_ADDR,@X,@Y,@Z)
    HeadX := X
    'HeadY := Y
    'HeadZ := Z
    X := 0
    y := 0
    Z := 0
    'hmc.GetTilt(C_SCL, C_ADDR,@X,@Y)
    'TiltX := X
    'TiltY := Y
    'X := 0
    'y := 0
    waitcnt(clkfreq/5+cnt)
  
PUB ADC 'XDUCERS------------------------------
dira[adcpwr]~~
outa[adcpwr] := 1
  repeat
    'ser.position(0,0)
    SPI.start(8,0)           '' Initialize SPI Engine with Clock Delay of 15us and Clock State of 1
      'waitcnt(cnt+clkfreq/80) '*10/100)
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, WrClock1)    '' Request Configuration Write
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, Clock1)      '' configure for ; CPU / Free-run mode
      'waitcnt(cnt+clkfreq/80) 
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, Wrsetup1)    '' Request Configuration Write
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, setup1)      '' configure for ; CPU / Free-run mode
      'waitcnt(cnt+clkfreq/80)
      repeat until comreg == %00001000 
        SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, ReadCom1)    '' Request Configuration Write
        comreg := SPI.SHIFTIN(ADCSDO, ADCCLK, SPI#MSBpre, 8)
        'ser.Str(String("Comreg1   = "))
        'ser.bin(comreg,8)
        'ser.newline
      'waitcnt(cnt+clkfreq/80)
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, ReadADC1)  '' Request to read 
      alt := SPI.SHIFTIN(ADCSDO, ADCCLK, SPI#MSBpre, 16)  '' read

      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, Wrsetup1)    '' Request Configuration Write
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, Stop1)
        'ser.Str(String("Alt   = "))
        'ser.dec(alt)
        'ser.newline
         
    'SPI.start(25,0)           '' Initialize SPI Engine with Clock Delay of 15us and Clock State of 1
      'waitcnt(cnt+clkfreq/80) '*10/100)     
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, WrClock2)    '' Request Configuration Write
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, Clock2)      '' configure for ; CPU / Free-run mode
      'waitcnt(cnt+clkfreq/80) 
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, Wrsetup2)    '' Request Configuration Write
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, setup2)      '' configure for ; CPU / Free-run mode
      'waitcnt(cnt+clkfreq/80)
      repeat until comreg == %00001001   
        SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, ReadCom2)    '' Request Configuration Write
        comreg := SPI.SHIFTIN(ADCSDO, ADCCLK, SPI#MSBpre, 8)
        'ser.Str(String("Comreg2 = "))
        'ser.bin(comreg,8)
        'ser.newline
      'waitcnt(cnt+clkfreq/80)
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, ReadADC2)  '' Request to read 
      Speed := SPI.SHIFTIN(ADCSDO, ADCCLK, SPI#MSBpre, 16)  '' read
      
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, Wrsetup2)    '' Request Configuration Write
      SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, Stop2)
        'ser.Str(String("Speed = "))
        'ser.dec(Speed)
        'ser.newline }
        'ser.Str(String("count = "))
        'ser.dec(TEMPVAR)
        'TEMPVAR ++
        
{  repeat
     SPI.start(15,0)
       waitcnt(clkfreq/50 + cnt)
       SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, ReadADC1)  '' Request to read 
       alt := SPI.SHIFTIN(ADCSDO, ADCCLK, SPI#MSBpre, 16)  '' read
       waitcnt(clkfreq/50 + cnt)
     SPI.start(15,0)
       waitcnt(clkfreq/50 + cnt)
       SPI.SHIFTOUT(ADCSDI, ADCCLK, SPI#MSBFIRST , 8, ReadADC2)  '' Request to read 
       Speed := SPI.SHIFTIN(ADCSDO, ADCCLK, SPI#MSBpre, 16)  '' read
       waitcnt(clkfreq/50 + cnt)    
 }
PRI i2cScan(MEMCLK) | value, ackbit
    i2cSlaveCounter := 0
    repeat i2cAddress from 0 to 127
        value :=  i2cAddress << 1 | 0
        ackbit := i2cObject.devicePresent(MEMCLK,value)
        if ackbit==false
          ''Ser.str(string("NAK"))
        else
          i2cSlaveCounter ++
          waitcnt(clkfreq/100+cnt)
        waitcnt(clkfreq/100 + cnt)
    'Ser.str(string("i2cScan found "))
    'Ser.dec(i2cSlaveCounter)
    'Ser.str(string(" devices!"))
    'Ser.newline 

pub StoreInfo  '  Stores Memory bank and EEPromaddr and EEPromLocation of shutdown 
  'Ser.Position(0,0)
  lastBANK := MEMSCL
    'Ser.str(string("LastBANK = "))
    'Ser.dec(LastBank)
    'Ser.newline
  lastADDR := EEPROMAddr
    'Ser.str(string("lastADDR = "))
    'Ser.bin(lastADDR,8)
    'Ser.newline
  LastEEPROM := EEPromLocation
    'Ser.str(string("LastEEPROM = "))
    'Ser.dec(LastEEPROM)
    'Ser.newline
  MEMSCL := MEMSCL1
  EEPROMAddr := %1010_0000
  EEPromLocation := $0004
  i2cObject.WriteLong(MEMSCL, EEPROMAddr, eepromLocation, lastEEPROM)
  EEPromLocation += 4
  i2cObject.WriteLong(MEMSCL, EEPROMAddr, eepromLocation, lastADDR)
  EEPromLocation += 4
  i2cObject.WriteLong(MEMSCL, EEPROMAddr, eepromLocation, lastBANK)     
     
dat
 
 filename     byte      "Drop__1.xls", 0    ' Zero is needed to prevent junk from being written to file
              Byte      "Drop__2.xls", 0
              byte      "Drop__3.xls", 0
              byte      "Drop__4.xls", 0
              Byte      "Drop__5.xls", 0
              byte      "Drop__6.xls", 0
              byte      "Drop__7.xls", 0
              Byte      "Drop__8.xls", 0
              byte      "Drop__9.xls", 0
              byte      "Drop_10.xls", 0
 FolderName   byte      "Folder_1", 0
              byte      "Folder_2", 0
              byte      "Folder_3", 0
              byte      "Folder_4", 0
              byte      "Folder_5", 0
              byte      "Folder_6", 0
              byte      "Folder_7", 0
              byte      "Folder_8", 0
              byte      "Folder_9", 0
              byte      "Folder10", 0
              byte      "Folder11", 0
              byte      "Folder12", 0
{
alt           Long
Speed         long
AccX          Long
Accy          Long
AccZ          Long
HeadX         Long
TiltX         Long
TiltY         Long
Temp          Long
Hum           Long
}